@@ -146,7 +146,8 @@ def _print_all(domains, expiration_timeout, cache_fuzzing, cache_path):
         metrics = []
         for domain in domains:
             instance_uuid = domain.UUIDString()
-            LOG.debug(f"Found instance {instance_uuid}")
+            instance_vcpus = domain.maxVcpus()
+            LOG.debug(f"Found instance {instance_uuid} ({instance_vcpus} vcpus)")
             exp = expiration_timeout + random.randrange(cache_fuzzing)
             cache = Cache(instance_uuid, cache_path, minutes=exp)
             metric = cache.check()
@@ -225,7 +226,8 @@ def _print_all(domains, expiration_timeout, cache_fuzzing, cache_path):
                 if roots == []:
                     metric = {
                         "resource_id" : domain.UUIDString(),
-                        "os_type": 'unknown',
+                        "vcpus": domain.maxVcpus(),
+                        "os_family": 'unknown',
                         "os_distro": 'unknown',
                         "os_info": 'unknown',
                         "os_version_major": 0,
@@ -238,7 +240,8 @@ def _print_all(domains, expiration_timeout, cache_fuzzing, cache_path):
                     for root in roots:
                         metric = {
                             "resource_id" : domain.UUIDString(),
-                            "os_type": g.inspect_get_type(root),
+                            "vcpus": domain.maxVcpus(),
+                            "os_family": g.inspect_get_type(root),
                             "os_distro": g.inspect_get_distro(root),
                             "os_info": g.inspect_get_osinfo(root),
                             "os_version_major": g.inspect_get_major_version(root),
@@ -263,6 +266,7 @@ def run_instance_poller():
     conf.register_cli_opts(common_opts)
     logging.register_options(conf)
     conf(project='ceilometer-instance-poller')
+    logging.setup(conf, conf.project)
 
 
     conn = _libvirt_connect()
